@@ -1,6 +1,7 @@
 # ADGSTUDIOS 2022
 import pyodbc
 import pandas as pd
+from pathlib import Path
 
 class adgsqlserver():
     def __init__(self, connectionstring):
@@ -14,6 +15,9 @@ class adgsqlserver():
             column = column + 1
         return results
 
+    def ReturnDrivers(self):
+        return pyodbc.drivers()
+
     def GetRecordsOfColumn(self, SelectQuery, ColumnName):
         try:
             conn = pyodbc.connect(self.connectionstring)
@@ -26,16 +30,19 @@ class adgsqlserver():
             return values
         except Exception as e:
             print(e)
+            return False
 
     def ExecuteQuery(self, Query):
         try:
             conn = pyodbc.connect(self.connectionstring)
             cursor = conn.cursor()
-            # fixed quotation mark error for data structures such as dict, list etc no longer need to use .replace('\'','\"') in code!
-            cursor.execute(Query.replace('\'','\"'))
+            cursor.execute(Query)
             cursor.commit()
+            return True
         except Exception as e:
             print(e)
+            return False
+            
 
     def GetRecordsAsDict(self, SelectQuery):
         try:
@@ -47,6 +54,7 @@ class adgsqlserver():
                      for row in cursor.fetchall()]}
         except Exception as e:
             print(e)
+            return False
 
     def CreateCSVTable(self,csvfile):
             df = pd.read_csv(csvfile)
@@ -81,7 +89,8 @@ class adgsqlserver():
                 cursor.commit()
                 return 'Table Created'
             except Exception as e:
-                return e
+                print(e)
+                return False
         
     def InsertCSVData(self,csvfile):
         df = pd.read_csv(csvfile)
@@ -97,7 +106,7 @@ class adgsqlserver():
 
             if index % 1000 == 0:
                 query = f'''
-                INSERT INTO {tablename}
+                INSERT INTO [{tablename}]
                 VALUES
                 {payload[:-2]}
                 '''
@@ -113,7 +122,7 @@ class adgsqlserver():
 
         if len(payload) > 0:
                 query = f'''
-                INSERT INTO {tablename}
+                INSERT INTO [{tablename}]
                 VALUES
                 {payload[:-2]}
                 '''
@@ -123,4 +132,11 @@ class adgsqlserver():
                     cursor.execute(query)
                     cursor.commit()
                 except Exception as e:
-                    print(e)
\ No newline at end of file
+                    print(e)
+
+        def InsertXMLSQLTable(self,path):
+            df = pd.read_xml(path)
+            datapath = Path(path)
+            df.to_csv(datapath.name+'.csv')
+            self.CreateCSVTable(datapath.name+'.csv')
+            self.InsertCSVData(datapath.name+'.csv')
\ No newline at end of file
